===========
astroph_new
===========

``astropy_new`` is a python functions to search for
`new astrophysics submissions <https://arxiv.org/list/astro-ph/new>`_
in `arXiv <https://arxiv.org>`_ based on the user interests and to create a
summarized document that can be easily opened in a browser.

- Docs: https://astroph-new.readthedocs.io

Installation: ``pip install git+https://github.com/radioshiny/astroph_new``

Features
========

- Managing user interests (subjects, author names, and keywords)
- Searching for new submissions in
  `astro-ph <https://arxiv.org/list/astro-ph/new>`_ based on the user interests
- Creating a summary report for the interested submissions

License
=======

All files are under MIT License, see `LISENCE <LICENSE>`_.
